.. _api:

.. module:: kplr

Python Interface
================

.. autoclass:: API
   :inherited-members:

Kepler Objects of Interest
--------------------------

.. autoclass:: KOI
   :inherited-members:

Confirmed Planets
-----------------

.. autoclass:: Planet
   :inherited-members:

Kepler Input Catalog Targets
----------------------------

.. autoclass:: Star
   :inherited-members:

Datasets
--------

.. autoclass:: LightCurve
   :inherited-members:

.. autoclass:: TargetPixelFile
   :inherited-members:
